.. _wavelets:

Wavelets Reference
==================

This is the reference of the wavelets available wiith the pyrwt package. Please refer to
the :ref:`tutorial <tutorial>` for further details, as the raw specifications
may not be enough to give full guidelines on their uses.


.. automodule:: rwt.wavelets


.. autofunction:: rwt.wavelets.waveletCoeffs


.. autofunction:: rwt.wavelets.waveletlist


.. autofunction:: rwt.wavelets.daubcqf


